@@ -41,7 +41,7 @@
 #include <dbus/dbus-glib-lowlevel.h>
 #include <gnome-keyring.h>
 #include <gconf/gconf-client.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
 #include "egg-console-kit.h"
@@ -56,7 +56,8 @@
 struct GpmControlPrivate
 {
 	GConfClient		*conf;
-	DkpClient		*client;
+	GSettings		*settings;
+	UpClient		*client;
 };
 
 enum {
@@ -103,7 +104,7 @@ gpm_control_shutdown (GpmControl *control, GError **error)
 /**
  * gpm_control_get_lock_policy:
  * @control: This class instance
- * @policy: The policy gconf string.
+ * @policy: The policy string.
  *
  * This function finds out if we should lock the screen when we do an
  * action. It is required as we can either use the gnome-screensaver policy
@@ -116,15 +117,15 @@ gpm_control_get_lock_policy (GpmControl *control, const gchar *policy)
 {
 	gboolean do_lock;
 	gboolean use_ss_setting;
-	/* This allows us to over-ride the custom lock settings set in gconf
+	/* This allows us to over-ride the custom lock settings set
 	   with a system default set in gnome-screensaver.
 	   See bug #331164 for all the juicy details. :-) */
-	use_ss_setting = gconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_USE_SCREENSAVER, NULL);
+	use_ss_setting = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_USE_SCREENSAVER);
 	if (use_ss_setting) {
-		do_lock = gconf_client_get_bool (control->priv->conf, GS_PREF_LOCK_ENABLED, NULL);
+		do_lock = gconf_client_get_bool (control->priv->conf, GS_CONF_PREF_LOCK_ENABLED, NULL);
 		egg_debug ("Using ScreenSaver settings (%i)", do_lock);
 	} else {
-		do_lock = gconf_client_get_bool (control->priv->conf, policy, NULL);
+		do_lock = g_settings_get_boolean (control->priv->settings, policy);
 		egg_debug ("Using custom locking settings (%i)", do_lock);
 	}
 	return do_lock;
@@ -157,20 +158,20 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	lock_gnome_keyring = gconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_SUSPEND, NULL);
+	lock_gnome_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_SUSPEND);
 	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK)
 			egg_warning ("could not lock keyring");
 	}
 
-	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_SUSPEND);
+	do_lock = gpm_control_get_lock_policy (control, GPM_SETTINGS_LOCK_ON_SUSPEND);
 	if (do_lock) {
 		throttle_cookie = gpm_screensaver_add_throttle (screensaver, "suspend");
 		gpm_screensaver_lock (screensaver);
 	}
 
-	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_sleep ();
 
@@ -178,7 +179,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
 
-	ret = dkp_client_suspend (control->priv->client, error);
+	ret = up_client_suspend_sync (control->priv->client, NULL, error);
 
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
@@ -189,7 +190,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 			gpm_screensaver_remove_throttle (screensaver, throttle_cookie);
 	}
 
-	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_wake ();
 
@@ -225,7 +226,7 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	lock_gnome_keyring = gconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_HIBERNATE, NULL);
+	lock_gnome_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_HIBERNATE);
 	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK) {
@@ -233,20 +234,20 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 		}
 	}
 
-	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_HIBERNATE);
+	do_lock = gpm_control_get_lock_policy (control, GPM_SETTINGS_LOCK_ON_HIBERNATE);
 	if (do_lock) {
 		throttle_cookie = gpm_screensaver_add_throttle (screensaver, "hibernate");
 		gpm_screensaver_lock (screensaver);
 	}
 
-	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_sleep ();
 
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
-	ret = dkp_client_hibernate (control->priv->client, error);
+	ret = up_client_hibernate_sync (control->priv->client, NULL, error);
 
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
@@ -257,7 +258,7 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 			gpm_screensaver_remove_throttle (screensaver, throttle_cookie);
 	}
 
-	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_wake ();
 
@@ -279,6 +280,7 @@ gpm_control_finalize (GObject *object)
 	control = GPM_CONTROL (object);
 
 	g_object_unref (control->priv->conf);
+	g_object_unref (control->priv->settings);
 	g_object_unref (control->priv->client);
 
 	g_return_if_fail (control->priv != NULL);
@@ -325,7 +327,8 @@ gpm_control_init (GpmControl *control)
 {
 	control->priv = GPM_CONTROL_GET_PRIVATE (control);
 
-	control->priv->client = dkp_client_new ();
+	control->priv->client = up_client_new ();
+	control->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 	control->priv->conf = gconf_client_get_default ();
 }
 
