@@ -37,10 +37,8 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
-#ifdef HAVE_DPMS_EXTENSION
 #include <X11/Xproto.h>
 #include <X11/extensions/dpms.h>
-#endif
 
 #include "egg-debug.h"
 #include "gpm-dpms.h"
@@ -81,8 +79,6 @@ gpm_dpms_error_quark (void)
 	return quark;
 }
 
-#ifdef HAVE_DPMS_EXTENSION
-
 /**
  * gpm_dpms_x11_get_mode:
  **/
@@ -192,30 +188,6 @@ gpm_dpms_x11_set_mode (GpmDpms *dpms, GpmDpmsMode mode, GError **error)
 	return TRUE;
 }
 
-#else  /* HAVE_DPMS_EXTENSION */
-
-/**
- * gpm_dpms_x11_get_mode:
- **/
-static gboolean
-gpm_dpms_x11_get_mode (GpmDpms *dpms, GpmDpmsMode *mode, GError **error)
-{
-	if (mode)
-		*mode = GPM_DPMS_MODE_ON;
-	return TRUE;
-}
-
-/**
- * gpm_dpms_x11_set_mode:
- **/
-static gboolean
-gpm_dpms_x11_set_mode (GpmDpms *dpms, GpmDpmsMode mode, GError **error)
-{
-	return FALSE;
-}
-
-#endif /* !HAVE_DPMS_EXTENSION */
-
 /**
  * gpm_dpms_mode_from_string:
  **/
@@ -307,10 +279,6 @@ gpm_dpms_poll_mode_cb (GpmDpms *dpms)
 	GpmDpmsMode mode;
 	GError *error = NULL;
 
-#ifndef HAVE_DPMS_EXTENSION
-	return FALSE;
-#endif
-
 	/* Try again */
 	ret = gpm_dpms_x11_get_mode (dpms, &mode, &error);
 	if (!ret) {
@@ -340,12 +308,9 @@ gpm_dpms_clear_timeouts (GpmDpms *dpms)
 		goto out;
 	}
 
-#ifdef HAVE_DPMS_EXTENSION
 	egg_debug ("set timeouts to zero");
 	ret = DPMSSetTimeouts (GDK_DISPLAY (), 0, 0, 0);
-#else
-	egg_warning ("no DPMS extension");
-#endif
+
 out:
 	return ret;
 }
@@ -381,6 +346,9 @@ gpm_dpms_init (GpmDpms *dpms)
 	/* DPMSCapable() can never change for a given display */
 	dpms->priv->dpms_capable = DPMSCapable (GDK_DISPLAY ());
 	dpms->priv->timer_id = g_timeout_add_seconds (GPM_DPMS_POLL_TIME, (GSourceFunc)gpm_dpms_poll_mode_cb, dpms);
+#if GLIB_CHECK_VERSION(2,25,8)
+	g_source_set_name_by_id (dpms->priv->timer_id, "[GpmDpms] poll");
+#endif
 
 	/* ensure we clear the default timeouts (Standby: 1200s, Suspend: 1800s, Off: 2400s) */
 	gpm_dpms_clear_timeouts (dpms);
