@@ -165,6 +165,7 @@ main (int argc, char *argv[])
 	GError *error = NULL;
 	GOptionContext *context;
 	gint ret;
+	guint timer_id;
 
 	const GOptionEntry options[] = {
 		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
@@ -269,7 +270,10 @@ main (int argc, char *argv[])
 	/* Only timeout and close the mainloop if we have specified it
 	 * on the command line */
 	if (timed_exit) {
-		g_timeout_add_seconds (20, (GSourceFunc) timed_exit_cb, loop);
+		timer_id = g_timeout_add_seconds (20, (GSourceFunc) timed_exit_cb, loop);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (timer_id, "[GpmMain] timed-exit");
+#endif
 	}
 
 	if (immediate_exit == FALSE) {
