@@ -38,7 +38,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 #include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
@@ -55,7 +54,7 @@ static void     gpm_tray_icon_finalize   (GObject	   *object);
 
 struct GpmTrayIconPrivate
 {
-	GConfClient		*conf;
+	GSettings		*settings;
 	GpmEngine		*engine;
 	GtkStatusIcon		*status_icon;
 	gboolean		 show_actions;
@@ -416,22 +415,17 @@ gpm_tray_icon_activate_cb (GtkStatusIcon *status_icon, GpmTrayIcon *icon)
 }
 
 /**
- * gpm_conf_gconf_key_changed_cb:
+ * gpm_tray_icon_settings_changed_cb:
  *
- * We might have to do things when the gconf keys change; do them here.
+ * We might have to do things when the settings change; do them here.
  **/
 static void
-gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmTrayIcon *icon)
+gpm_tray_icon_settings_changed_cb (GSettings *settings, const gchar *key, GpmTrayIcon *icon)
 {
-	GConfValue *value;
 	gboolean allowed_in_menu;
 
-	value = gconf_entry_get_value (entry);
-	if (value == NULL)
-		return;
-
-	if (strcmp (entry->key, GPM_CONF_UI_SHOW_ACTIONS) == 0) {
-		allowed_in_menu = gconf_value_get_bool (value);
+	if (g_strcmp0 (key, GPM_SETTINGS_SHOW_ACTIONS) == 0) {
+		allowed_in_menu = g_settings_get_boolean (settings, key);
 		gpm_tray_icon_enable_actions (icon, allowed_in_menu);
 	}
 }
@@ -450,13 +444,9 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 
 	icon->priv->engine = gpm_engine_new ();
 
-	icon->priv->conf = gconf_client_get_default ();
-	/* watch gnome-power-manager keys */
-	gconf_client_add_dir (icon->priv->conf, GPM_CONF_DIR,
-			      GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
-	gconf_client_notify_add (icon->priv->conf, GPM_CONF_DIR,
-				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
-				 icon, NULL, NULL);
+	icon->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
+	g_signal_connect (icon->priv->settings, "changed",
+			  G_CALLBACK (gpm_tray_icon_settings_changed_cb), icon);
 
 	icon->priv->status_icon = gtk_status_icon_new ();
 	g_signal_connect_object (G_OBJECT (icon->priv->status_icon),
@@ -468,7 +458,7 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 				 G_CALLBACK (gpm_tray_icon_activate_cb),
 				 icon, 0);
 
-	allowed_in_menu = gconf_client_get_bool (icon->priv->conf, GPM_CONF_UI_SHOW_ACTIONS, NULL);
+	allowed_in_menu = g_settings_get_boolean (icon->priv->settings, GPM_SETTINGS_SHOW_ACTIONS);
 	gpm_tray_icon_enable_actions (icon, allowed_in_menu);
 }
 
